﻿/**********************************************************
 * Jexus Owin开放接口Microsoft.Owin适配器
 * --------------------------------------------------------
 * 本适配器最初设计人为宇内流云，时间是2014年6月。
 * 本适配器开源，任何人都可以修改和自由使用。
 * 如有修改完善，请尽快将源码和修修说明返馈给宇内流云，以便统一更新
 * *******************************************************************/

/***********************************************************
 * 使用方法：
 * 1、编译得到Jws.OwinAdapter.MsOwin.dll。
 * 2、将编译得到的dll连同Owin.dll、Microsoft.Owin.dll等文件
 *    一同放置到网站的bin文件夹中
 * 3、在对应网站的jws网站配置文件中加入一句，声明要使用的适配器：
 *    OwinMain=Jws.OwinAdapter.MsOwin.dll,Jws.OwinAdapter.MsOwin.Adapter
 * 4、重启Jexus让配置生效。
 *************************************************************************/


using System;
using System.Collections.Generic;
using Microsoft.Owin.Builder;
using System.Threading.Tasks;

namespace Jws.OwinAdapter.MsOwin
{

    /// <summary>
    /// 针对Microsoft.Owin的JWS开放接口适配器
    /// <para>本接口适合兼容Microsoft.Owin规范的应用</para>
    /// </summary>
    class Adapter
    {
        static Func<IDictionary<string, object>, Task> _owinApp;

        /// <summary>
        /// 配配器构造函数
        /// </summary>
        public Adapter()
        {
            var configures = Configuration.Get();
            if (configures == null || configures.Count <= 0) return;

            var builder = new AppBuilder();
            foreach (var c in configures)
            {
                c(builder);
            }
            _owinApp = builder.Build();
        }


        /// <summary>
        /// JWS所需要的主调函数
        /// <para>每个请求到来，JWS都会调用这个函数</para>
        /// </summary>
        /// <param name="env">新请求的环境字典，具体内容参见OWIN标准</param>
        /// <returns>返回一个正在运行或已经完成的任务</returns>
        public Task OwinMain(IDictionary<string, object> env)
        {
            if (_owinApp == null) return null;

            //将请求交给Microsoft.Owin处理
            return _owinApp(env);

        }




    } //end class


} //end namespace
